==> haskell-gio-0.13.8.2-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 gio
version:              0.13.8.2
visibility:           public
id:                   gio-0.13.8.2-Bh20SNhX33nBBlryOpTKil
key:                  gio-0.13.8.2-Bh20SNhX33nBBlryOpTKil
license:              LGPL-2.1-only
copyright:            (c) 2001-2010 The Gtk2Hs Team
maintainer:           gtk2hs-users@lists.sourceforge.net
author:               Peter Gavin, Andy Stewart
stability:            stable
homepage:             http://projects.haskell.org/gtk2hs/
synopsis:             Binding to GIO
description:
    GIO is striving to provide a modern, easy-to-use VFS API that sits at the right level in the library stack.
    The goal is to overcome the shortcomings of GnomeVFS and provide an API that is
    so good that developers prefer it over raw POSIX calls.
    Among other things that means using GObject.
    It also means not cloning the POSIX API, but providing higher-level, document-centric interfaces.

category:             System
abi:                  1b8a0d4ebfeffdc9e1b2c818805ee0e4
exposed:              True
exposed-modules:
    System.GIO System.GIO.Async.AsyncResult
    System.GIO.Async.Cancellable System.GIO.Enums
    System.GIO.File.AppInfo System.GIO.File.ContentType
    System.GIO.File.File System.GIO.File.FileAttribute
    System.GIO.File.FileEnumerator System.GIO.File.FileInfo
    System.GIO.File.FileMonitor System.GIO.File.IOError
    System.GIO.File.MountOperation System.GIO.Icons.Emblem
    System.GIO.Icons.EmblemedIcon System.GIO.Icons.FileIcon
    System.GIO.Icons.Icon System.GIO.Icons.ThemedIcon System.GIO.Types
    System.GIO.Volumes.Drive System.GIO.Volumes.Mount
    System.GIO.Volumes.Volume System.GIO.Volumes.VolumeMonitor

hidden-modules:       System.GIO.Signals
import-dirs:          /usr/lib/ghc-9.0.2/site-local/gio-0.13.8.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/gio-0.13.8.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gio
hs-libraries:         HSgio-0.13.8.2-Bh20SNhX33nBBlryOpTKil
extra-libraries:      gio-2.0 gobject-2.0 glib-2.0
include-dirs:
    /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/sysprof-4 /usr/include/libmount /usr/include/blkid

depends:
    array-0.5.4.0 base-4.15.1.0 bytestring-0.10.12.1 containers-0.6.4.1
    glib-0.13.8.2-8GnoispwAgZJGuZrzN18wE mtl-2.2.2

haddock-interfaces:   /usr/share/doc/haskell-gio/html/gio.haddock
haddock-html:         /usr/share/doc/haskell-gio/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gio-0.13.10.0-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 gio
version:              0.13.10.0
visibility:           public
id:                   gio-0.13.10.0-Kr0po4zCAQ4E9bYYS8bSY
key:                  gio-0.13.10.0-Kr0po4zCAQ4E9bYYS8bSY
license:              LGPL-2.1-only
copyright:            (c) 2001-2010 The Gtk2Hs Team
maintainer:           gtk2hs-users@lists.sourceforge.net
author:               Peter Gavin, Andy Stewart
stability:            stable
homepage:             http://projects.haskell.org/gtk2hs/
synopsis:             Binding to GIO
description:
    GIO is striving to provide a modern, easy-to-use VFS API that sits at the right level in the library stack.
    The goal is to overcome the shortcomings of GnomeVFS and provide an API that is
    so good that developers prefer it over raw POSIX calls.
    Among other things that means using GObject.
    It also means not cloning the POSIX API, but providing higher-level, document-centric interfaces.

category:             System
abi:                  206c15d9569d9f823d1a5997eacf61ad
exposed:              True
exposed-modules:
    System.GIO System.GIO.Async.AsyncResult
    System.GIO.Async.Cancellable System.GIO.Enums
    System.GIO.File.AppInfo System.GIO.File.ContentType
    System.GIO.File.File System.GIO.File.FileAttribute
    System.GIO.File.FileEnumerator System.GIO.File.FileInfo
    System.GIO.File.FileMonitor System.GIO.File.IOError
    System.GIO.File.MountOperation System.GIO.Icons.Emblem
    System.GIO.Icons.EmblemedIcon System.GIO.Icons.FileIcon
    System.GIO.Icons.Icon System.GIO.Icons.ThemedIcon System.GIO.Types
    System.GIO.Volumes.Drive System.GIO.Volumes.Mount
    System.GIO.Volumes.Volume System.GIO.Volumes.VolumeMonitor

hidden-modules:       System.GIO.Signals
import-dirs:          /usr/lib/ghc-9.0.2/site-local/gio-0.13.10.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/gio-0.13.10.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gio
hs-libraries:         HSgio-0.13.10.0-Kr0po4zCAQ4E9bYYS8bSY
extra-libraries:      gio-2.0 gobject-2.0 glib-2.0
include-dirs:
    /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/sysprof-4 /usr/include/libmount /usr/include/blkid

depends:
    array-0.5.4.0 base-4.15.1.0 bytestring-0.10.12.1 containers-0.6.4.1
    glib-0.13.8.2-KqtWyYf6Ht46ir8v1cawtt mtl-2.2.2

haddock-interfaces:   /usr/share/doc/haskell-gio/html/gio.haddock
haddock-html:         /usr/share/doc/haskell-gio/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
